library(ggplot2)
library(zoo)

rm(list=ls()) ; gc()

load("/esarchive/scratch/molmo/CLIMCAT_MJ/CMIP6/series.indices.mon.CMIP6.ssp585.Rdata")

#Seasonal
#load("series.indices.mon.CMIP6.historical.Rdata")
indices <- c("txx","txn","tnx","tnn","tx90p","tx10p","tn90p","tn10p",
             "rx5day","rx1day")

test <- list()
for(i in 1:length(indices)){
  test[[i]] <- list()
  for(m in 1:length(series.indices[[i]])){
    test[[i]][[m]] <- do.call("rbind",series.indices[[i]][[m]])
  }
}

test2 <- list()
for(i in 1:length(indices)){
  test2[[i]] <- do.call("rbind",test[[i]])
}

test3 <- do.call("rbind",test2)
test3$Index <- toupper(test3$Index)
#test3$Model[which(test3$Model=="")] <- "ERA5"

Model <- unique(test3$Model)
#Model <- Model[order(Model)]

#test3$Model <- factor(test3$Model,levels=rev(c("ERA5",Model[-which(Model=="ERA5")])))
test3$Index <- factor(test3$Index,levels=toupper(c("tnn","tnx","txn","txx","tn10p","tn90p","tx10p","tx90p",
                                                   "rx1day","rx5day")))

test3$Season <- factor(test3$Season,levels=c("Summer","Autumn","Winter","Spring"))

test4 <- test3

color_order = c(
  "red",
  "yellow",
  "mediumseagreen",
  "navy",
  "darkorchid",
  "deeppink",
  "peru",
  "#8c564b",
  "yellowgreen",
  "darkgreen",
  "deepskyblue",
  "lightcyan",
  "#C0C0C0",
  "#7f7f7f",
  "black")

mean.smooth <- function(x){
  y <- NA
  for(i in seq_along(x)){
    if(i>2 & i<=(length(x)-2)){
      y[i] <- mean(x[c((i-2):(i+2))],na.rm=T)
    }else{
      y [i] <- NA
    }
  }
  return(y)
}

#Summer
Models1 <- c("FGOALS-g3","INM-CM4-8","KIOST-ESM","IPSL-CM6A-LR","MIROC6")
Models2 <- c("CanESM5","EC-Earth3","FGOALS-g3","IPSL-CM6A-LR","MIROC6")
Models3 <- c("EC-Earth3-CC","EC-Earth3-Veg-LR","GFDL-ESM4","IPSL-CM6A-LR","MIROC6")

#ModelsW <- c("AWI-CM-1-1-MR","INM-CM5-0","CMCC-ESM2","KIOST-ESM","NorESM2-LM")
ens1 <- subset(test3,Model%in%Models1 & Region=="EuroMediterranean")
ens2 <- subset(test3,Model%in%Models2 & Region=="EuroMediterranean")
ens3 <- subset(test3,Model%in%Models3 & Region=="EuroMediterranean")
#ens4 <- subset(test3,Model%in%ModelsW & Region=="EuroMediterranean")

ens1.m <- aggregate(Serie~Index+Year+Season,ens1,FUN="mean",na.rm=T)
ens2.m <- aggregate(Serie~Index+Year+Season,ens2,FUN="mean",na.rm=T)
ens3.m <- aggregate(Serie~Index+Year+Season,ens3,FUN="mean",na.rm=T)
#ens4.m <- aggregate(Serie~Index+Year+Season,ens4,FUN="mean",na.rm=T)

ens1.m$Ensemble <- 1
ens2.m$Ensemble <- 2
ens3.m$Ensemble <- 3
#ens4.m$Ensemble <- 4

ens <- rbind(ens1.m,ens2.m,ens3.m)

for(i in seq_along(unique(ens$Index))){
  for(j in seq_along(unique(ens$Season))){
    for(k in seq_along(unique(ens$Ensemble))){
      test <- subset(ens,Index==unique(ens$Index)[i] & Season==unique(ens$Season)[j] & Ensemble==unique(ens$Ensemble)[k])$Serie
      test.sm <- mean.smooth(test)
      ens$Serie[which(ens$Index==unique(ens$Index)[i] & ens$Season==unique(ens$Season)[j] & ens$Ensemble==unique(ens$Ensemble)[k])] <- test.sm
    }
  }
}

p <- ggplot(data=subset(ens,Ensemble%in%c(1,2,3) & Year %in%(2070:2100) & Season %in%c("Summer")),aes(x=Year,y=Serie,col=as.factor(Ensemble))) + 
  geom_line() + facet_wrap(~Index,scales = "free",ncol=4) + theme_bw() +#+ ggtitle("Summer")+
  scale_color_manual(values=color_order[c(1,5,8)]) + theme(legend.position = "none")

png(filename="seriesCLIMSIPS_jja.png",res=600,width=5000,height =2500)
gridExtra::grid.arrange(p,nrow=1)
dev.off()

png(filename="temp2040jja.png")
plot(p)
dev.off()

#Winter
Models1 <- c("FGOALS-g3","INM-CM4-8","KIOST-ESM","IPSL-CM6A-LR","MIROC6")
Models2 <- c("CanESM5","EC-Earth3","GFDL-CM4","INM-CM4-8","MPI-ESM1-2-HR")
Models3 <- c("EC-Earth3-CC","EC-Earth3-Veg-LR","GFDL-ESM4","IPSL-CM6A-LR","MIROC6")

#ModelsW <- c("AWI-CM-1-1-MR","INM-CM5-0","CMCC-ESM2","KIOST-ESM","NorESM2-LM")
ens1 <- subset(test3,Model%in%Models1 & Region=="EuroMediterranean")
ens2 <- subset(test3,Model%in%Models2 & Region=="EuroMediterranean")
ens3 <- subset(test3,Model%in%Models3 & Region=="EuroMediterranean")
#ens4 <- subset(test3,Model%in%ModelsW)

ens1.m <- aggregate(Serie~Index+Year+Season,ens1,FUN="mean",na.rm=T)
ens2.m <- aggregate(Serie~Index+Year+Season,ens2,FUN="mean",na.rm=T)
ens3.m <- aggregate(Serie~Index+Year+Season,ens3,FUN="mean",na.rm=T)
#ens4.m <- aggregate(Serie~Index+Year+Season,ens4,FUN="mean",na.rm=T)

ens1.m$Ensemble <- 1
ens2.m$Ensemble <- 2
ens3.m$Ensemble <- 3
#ens4.m$Ensemble <- 4

ens <- rbind(ens1.m,ens2.m,ens3.m)

for(i in seq_along(unique(ens$Index))){
  for(j in seq_along(unique(ens$Season))){
    for(k in seq_along(unique(ens$Ensemble))){
      test <- subset(ens,Index==unique(ens$Index)[i] & Season==unique(ens$Season)[j] & Ensemble==unique(ens$Ensemble)[k])$Serie
      test.sm <- mean.smooth(test)
      ens$Serie[which(ens$Index==unique(ens$Index)[i] & ens$Season==unique(ens$Season)[j] & ens$Ensemble==unique(ens$Ensemble)[k])] <- test.sm
    }
  }
}

g <- ggplot(data=subset(ens,Ensemble%in%c(1,2,3)  & Year %in% c(2070:2100) & Season %in%c("Winter")),aes(x=Year,y=Serie,col=as.factor(Ensemble)))  + facet_wrap(~Index,scales = "free",ncol=2) +
  theme_bw() + geom_line() + scale_color_manual(values=color_order[c(1,10,15)])+ 
  theme(legend.position = "none") #+ ggtitle("Winter")

png(filename="seriesCLIMSIPS_djf.png",res=600,width=5000,height =2500)
gridExtra::grid.arrange(g,nrow=1)
dev.off()


g <- ggplot(data=subset(ens,Ensemble%in%c(1,2,3)  & Year %in% c(2070:2100) & Season %in%c("Winter")),aes(x=Year,y=Serie,col=as.factor(Ensemble)))  + facet_wrap(~Index,scales = "free",ncol=4) +
  theme_bw() + geom_line() + scale_color_manual(values=color_order[c(1,10,15)])+ 
  theme(legend.position = "none") #+ ggtitle("Winter")
